@@ -1,21 +1,4 @@
 # #
-# This software was developed and / or modified by Raytheon Company,
-# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
-#
-# U.S. EXPORT CONTROLLED TECHNICAL DATA
-# This software product contains export-restricted data whose
-# export/transfer/disclosure is restricted by U.S. law. Dissemination
-# to non-U.S. persons whether in the United States or abroad requires
-# an export license or other authorization.
-#
-# Contractor Name:        Raytheon Company
-# Contractor Address:     6825 Pine Street, Suite 340
-#                         Mail Stop B8
-#                         Omaha, NE 68106
-#                         402.291.0100
-#
-# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
-# further licensing information.
 # #
 
 #
@@ -28,6 +11,7 @@
 #    Date            Ticket#       Engineer       Description
 #    ------------    ----------    -----------    --------------------------
 #    06/03/13         #2023        dgilling      Initial Creation.
+#    11/10/16         #5900        bsteffen      Correct grid shape
 #
 #
 
@@ -51,7 +35,7 @@ class PyGridData(IGridData, PyData.PyData):
         ny = ny
         self.__parameter = gridDataRecord.getParameter()
         self.__unit = gridDataRecord.getUnit()
-        self.__gridData = numpy.reshape(numpy.array(gridDataRecord.getGridData()), (nx, ny))
+        self.__gridData = numpy.reshape(numpy.array(gridDataRecord.getGridData()), (ny, nx))
         self.__latLonGrid = latLonGrid
 
     def getParameter(self):
