@@ -1,21 +1,4 @@
 ##
-# This software was developed and / or modified by Raytheon Company,
-# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
-#
-# U.S. EXPORT CONTROLLED TECHNICAL DATA
-# This software product contains export-restricted data whose
-# export/transfer/disclosure is restricted by U.S. law. Dissemination
-# to non-U.S. persons whether in the United States or abroad requires
-# an export license or other authorization.
-#
-# Contractor Name:        Raytheon Company
-# Contractor Address:     6825 Pine Street, Suite 340
-#                         Mail Stop B8
-#                         Omaha, NE 68106
-#                         402.291.0100
-#
-# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
-# further licensing information.
 ##
 
 
@@ -36,7 +19,7 @@
 #
 
 from thrift.transport import TTransport
-import SelfDescribingBinaryProtocol, ThriftSerializationContext
+from . import SelfDescribingBinaryProtocol, ThriftSerializationContext
 
 class DynamicSerializationManager:
 
@@ -66,4 +49,4 @@ class DynamicSerializationManager:
         return self.transport.getvalue()
 
     def _serialize(self, ctx, obj):
-        ctx.serializeMessage(obj)
\ No newline at end of file
+        ctx.serializeMessage(obj)
